import axios from 'axios';
import { API_BASE_URL } from '@/config/api-config'; // api-config.ts can be moved to src/config/

// Create axios instance
const api = axios.create({
  baseURL: API_BASE_URL, // API_BASE_URL should come from env or config
  headers: {
    'Content-Type': 'application/json',
  },
});

// Request interceptor
api.interceptors.request.use(
  (config) => {
    const token = localStorage.getItem('token'); // Or use useStorage from VueUse
    if (token) {
      config.headers.Authorization = `Bearer ${token}`;
    }
    return config;
  },
  (error) => {
    return Promise.reject(error); // Simpler error handling
  }
);

// Response interceptor
api.interceptors.response.use(
  (response) => response,
  async (error) => {
    const originalRequest = error.config;

    if (error.response?.status === 401 && !originalRequest._retry) {
      originalRequest._retry = true;
      try {
        const refreshToken = localStorage.getItem('refreshToken');
        if (!refreshToken) {
          // No refresh token, logout or redirect
          // This logic might be better handled in the auth store or router
          console.error('No refresh token, redirecting to login');
          // Consider emitting an event or calling an auth store action
          // window.location.href = '/auth/login'; // Avoid direct manipulation if possible
          return Promise.reject(error);
        }

        const response = await api.post('/api/v1/auth/refresh-token', { // Ensure this path is correct
          refresh_token: refreshToken,
        });

        const { access_token: newAccessToken, refresh_token: newRefreshToken } = response.data;
        localStorage.setItem('token', newAccessToken);
        if (newRefreshToken) localStorage.setItem('refreshToken', newRefreshToken); // Backend might not always send a new one

        originalRequest.headers.Authorization = `Bearer ${newAccessToken}`;
        return api(originalRequest);
      } catch (refreshError) {
        console.error('Refresh token failed:', refreshError);
        localStorage.removeItem('token');
        localStorage.removeItem('refreshToken');
        // window.location.href = '/auth/login'; // Avoid direct manipulation
        return Promise.reject(refreshError);
      }
    }
    return Promise.reject(error);
  }
);

// Export the original axios too if some parts of your app used it directly
const globalAxios = axios;

export { api, globalAxios };

// Re-export apiClient for convenience, using the new api instance
// from src/config/api.ts
import { API_VERSION, API_ENDPOINTS } from '@/config/api-config';

export const getApiUrl = (endpoint: string): string => {
    // Assuming API_BASE_URL already includes http://localhost:8000
    // and endpoint starts with /
    // The original `getApiUrl` added /api/v1, ensure this is correct for your setup
    return `${API_BASE_URL}/api/${API_VERSION}${endpoint}`;
};

export const apiClient = {
    get: (endpoint: string, config = {}) => api.get(getApiUrl(endpoint), config),
    post: (endpoint: string, data = {}, config = {}) => api.post(getApiUrl(endpoint), data, config),
    put: (endpoint: string, data = {}, config = {}) => api.put(getApiUrl(endpoint), data, config),
    patch: (endpoint: string, data = {}, config = {}) => api.patch(getApiUrl(endpoint), data, config),
    delete: (endpoint: string, config = {}) => api.delete(getApiUrl(endpoint), config),
};

export { API_ENDPOINTS }; // Also re-export for convenience